@@ -2,15 +2,15 @@
 ##'
 ##' An 8-color colorblind safe qualitative discrete palette from
 ##' \url{http://jfly.iam.u-tokyo.ac.jp/color} and the
-##' \href{http://wiki.stdout.org/rcookbook/Graphs/Colors%20(ggplot2)/#a-colorblind-friendly-palette}{Cookbook
+##' \href{http://wiki.stdout.org/rcookbook/Graphs/Colors_(ggplot2)/#a-colorblind-friendly-palette}{Cookbook
 ##' for R}.
 ##'
 ##' @rdname colorblind
 ##' @export
 ##' @inheritParams ggplot2::scale_colour_hue
 ##' @family colour
-##' @seealso The \pkg{dichromat} package, \code{\link[scales]{dichromat_pal}}, and \code{\link{scale_color_tableau}} for other
-##' colorblind palettes.
+##' @seealso The \pkg{dichromat} package, \code{\link[scales]{dichromat_pal}},
+##'  and \code{\link{scale_color_tableau}} for other colorblind palettes.
 ##' @examples
 ##' library(scales)
 ##' show_col(colorblind_pal()(8))
@@ -24,7 +24,7 @@ colorblind_pal <- function() {
 ##' @rdname colorblind
 ##' @export
 scale_colour_colorblind <- function(...) {
-    discrete_scale("colour", "economist", colorblind_pal(), ...)
+    discrete_scale("colour", "colorblind", colorblind_pal(), ...)
 }
 
 ##' @rdname colorblind
